<?php

/**
 * @var \Illuminate\Database\Eloquent\Collection $card
 * @var int $page_number
 * @var \kernel\CgView $view
 */

use kernel\app_modules\card\models\Card;
use Itguild\EloquentTable\EloquentDataProvider;
use Itguild\EloquentTable\ListEloquentTable;
use kernel\widgets\IconBtn\IconBtnCreateWidget;
use kernel\widgets\IconBtn\IconBtnDeleteWidget;
use kernel\widgets\IconBtn\IconBtnEditWidget;
use kernel\widgets\IconBtn\IconBtnViewWidget;

$view->setTitle("Список транзакций");
$view->setMeta([
    'description' => 'Список транзакций системы'
]);

//Для использования таблицы с моделью, необходимо создать таблицу в базе данных
$table = new ListEloquentTable(new EloquentDataProvider(\kernel\app_modules\card\models\CardTransaction::class, [
    'currentPage' => $page_number,
    'perPage' => 8,
    'params' => ["class" => "table table-bordered", "border" => "2"],
    'baseUrl' => "/admin/card_transaction"
]));

$table->beforePrint(function () {
    $count = \kernel\app_modules\card\models\CardTransaction::all()->count();
    $html = IconBtnCreateWidget::create(['url' => '/admin/card_transaction/create'])->run();
    $html .= "<div>Всего записей: $count</div>";

    return $html;
});

$table->columns([
    'status' => [
        'value' => function ($data) {
            return \kernel\app_modules\card\models\CardTransaction::getStatus()[$data];
        }
    ],
    'from' => [
        'value' => function ($data) {
            if ((int)$data === 1001){
                $username = "System";
            }
            else {
                $username = Card::find($data)->username ?? '';
            }
            return $username;
        }
    ],
    'to' => [
        'value' => function ($data) {
            if ((int)$data === 1001){
                $username = "System";
            }
            else {
                $username = Card::find($data)->username ?? '';
            }
            return $username;
        }
    ],
]);

$table->addAction(function($row) {
    return IconBtnViewWidget::create(['url' => '/admin/card_transaction/' . $row['id']])->run();
});
//$table->addAction(function($row) {
//    return IconBtnEditWidget::create(['url' => '/admin/card_transaction/update/' . $row['id']])->run();
//});
//$table->addAction(function($row) {
//    return IconBtnDeleteWidget::create(['url' => '/admin/card_transaction/delete/' . $row['id']])->run();
//});
$table->create();
$table->render();